@@ -283,17 +283,16 @@ class Schema(object):
 
     def _gen_field(self
         , name:str=None
-        , ftype:str='string'
+        , ftype=str
         , size:int=50
         , default=None
         , primary_key:bool=False
         , auto_increment:int=0
         , optional:bool=False):
+        if ftype not in (int, str, float, bool, bytes):
+            raise Exception("Invalid type.")
         if not name:
             name = self.gen_field_name()
-        if ftype=='string':
-            warnings.warn('Use Python types to define the data type. Instead of using "string" use "str".')
-            ftype = str
         f = self._Field(name=name
             , ftype=ftype
             , size=size
